==> _private_core_network-0.0.79.tar.gz: lib/network_resources/provider/client.dart <==
import 'dart:convert';

import 'package:dio/native_imp.dart';
import 'package:dio/dio.dart';
import 'package:flutter/foundation.dart';
import 'package:get/get.dart' as getx;
import 'package:logger/logger.dart';
import 'package:_private_core/_private_core.dart';

const String METHOD_GET = "GET";
const String METHOD_POST = "POST";
const String METHOD_PUT = "PUT";
const String METHOD_DELETE = "DELETE";

_parseAndDecode(String response) {
  return jsonDecode(response);
}

parseJson(String text) {
  return compute(_parseAndDecode, text);
}

class AppClients extends DioForNative {
  static final _logger = Logger();
  static AppClients? _instance;
  static bool _enableErrorHandler = true;

  factory AppClients(
      {required bool requiredToken,
      bool isAuthorizationCustom = false,
      String? token,
      String? baseUrl,
      bool enableErrorHandler = true,
      BaseOptions? options}) {
    _enableErrorHandler = enableErrorHandler;

    _instance ??=
        AppClients._(baseUrl: baseUrl ?? arckipelbaseUrl, options: options);
    if (options != null) _instance!.options = options;
    _instance!.options.baseUrl = baseUrl ?? arckipelbaseUrl;
    (_instance!.transformer as DefaultTransformer).jsonDecodeCallback =
        parseJson;
    if ((token == null || token.isEmpty)) {
      if (requiredToken) {
        _logger.w('Request RequiredToken but your token is null!');
      }
      _instance!.options.headers.remove(r'Authorization');
    } else if (requiredToken) {
      _instance!.options.headers.addAll({
        r'Authorization':
            isAuthorizationCustom ? token : ('Bearer $token')
      });
    }
    _logger.d("Header: ${_instance!.options.headers}");
    _instance!.options.headers.addAll({
      "Access-Control-Allow-Origin": "*",
      "Access-Control-Allow-Credentials": true,
      "Access-Control-Allow-Headers":
          "Origin,Content-Type,X-Amz-Date,Authorization,X-Api-Key,X-Amz-Security-Token,locale",
      "Access-Control-Allow-Methods": "POST, OPTIONS"
    });
    return _instance!;
  }

  AppClients._({String? baseUrl, BaseOptions? options}) : super(options) {
    interceptors.add(InterceptorsWrapper(
      onRequest: _requestInterceptor,
      onResponse: _responseInterceptor,
      onError: _errorInterceptor,
    ));
    this.options.baseUrl = baseUrl ?? arckipelbaseUrl;
  }

  _requestInterceptor(
      RequestOptions ops, RequestInterceptorHandler handler) async {
    String message =
        "${ops.method}: ${ops.uri}\nQueryParameters: ${ops.queryParameters}";
    switch (ops.method) {
      case METHOD_GET:
        break;
      case METHOD_POST:
      case METHOD_PUT:
      case METHOD_DELETE:
        if (ops.data is Map) {
          message += "\nData is Map: ${ops.data}";
        } else if (ops.data is FormData) {
          message +=
              "\nData is FormData: ${ops.data.fields}\nFiles: ${ops.data.files}";
        }
        break;
      default:
        break;
    }
    _logger.d(message);
    ops.connectTimeout = 30000;
    ops.receiveTimeout = 30000;
    handler.next(ops);
  }

  _responseInterceptor(Response r, ResponseInterceptorHandler handler) {
    _logger.i(
        "Response ${r.requestOptions.uri}: ${r.statusCode}\nData: ${r.data}");
    handler.next(r);
  }

  _errorInterceptor(DioError e, ErrorInterceptorHandler handler) {
    _logger.e(
        "${e.requestOptions.uri}\n${e.type} - ${e.message}\nData: ${e.response?.data}");
    // if (_enableErrorHandler) ErrorHandling().onError(dioError);
    if (PCoreConfig.instance.coreOptions.errorInterceptor != null) {
      PCoreConfig.instance.coreOptions.errorInterceptor!(e);
    }
    handler.next(e);
  }
}

==> _private_core_network-1.0.14.tar.gz: lib/network_resources/provider/client.dart <==
import 'dart:convert';

import 'package:dio/native_imp.dart';
import 'package:dio/dio.dart';
import 'package:flutter/foundation.dart';
import 'package:get/get.dart' as getx;
import 'package:logger/logger.dart';
import 'package:_private_core/_private_core.dart';

const String METHOD_GET = "GET";
const String METHOD_POST = "POST";
const String METHOD_PUT = "PUT";
const String METHOD_DELETE = "DELETE";

_parseAndDecode(String response) {
  return jsonDecode(response);
}

parseJson(String text) {
  return compute(_parseAndDecode, text);
}

class AppClients extends DioForNative {
  static final _logger = Logger();
  static AppClients? _instance;
  static bool _enableErrorHandler = true;

  factory AppClients(
      {required bool requiredToken,
      bool isAuthorizationCustom = false,
      String? token,
      String? baseUrl,
      bool enableErrorHandler = true,
      BaseOptions? options}) {
    _enableErrorHandler = enableErrorHandler;

    _instance ??=
        AppClients._(baseUrl: baseUrl ?? arckipelbaseUrl, options: options);
    if (options != null) _instance!.options = options;
    _instance!.options.baseUrl = baseUrl ?? arckipelbaseUrl;
    (_instance!.transformer as DefaultTransformer).jsonDecodeCallback =
        parseJson;
    if ((token == null || token.isEmpty)) {
      if (requiredToken) {
        _logger.w('Request RequiredToken but your token is null!');
      }
      _instance!.options.headers.remove(r'Authorization');
    } else if (requiredToken) {
      _instance!.options.headers.addAll({
        r'Authorization': isAuthorizationCustom ? token : ('Bearer $token')
      });
    }
    _logger.d("Header: ${_instance!.options.headers}");
    _instance!.options.headers.addAll({
      "Access-Control-Allow-Origin": "*",
      "Access-Control-Allow-Credentials": true,
      "Access-Control-Allow-Headers":
          "Origin,Content-Type,X-Amz-Date,Authorization,X-Api-Key,X-Amz-Security-Token,locale",
      "Access-Control-Allow-Methods": "POST, OPTIONS"
    });
    return _instance!;
  }

  AppClients._({String? baseUrl, BaseOptions? options}) : super(options) {
    interceptors.add(InterceptorsWrapper(
      onRequest: _requestInterceptor,
      onResponse: _responseInterceptor,
      onError: _errorInterceptor,
    ));
    this.options.baseUrl = baseUrl ?? arckipelbaseUrl;
  }

  _requestInterceptor(
      RequestOptions ops, RequestInterceptorHandler handler) async {
    String message =
        "${ops.method}: ${ops.uri}\nQueryParameters: ${ops.queryParameters}";
    switch (ops.method) {
      case METHOD_GET:
        break;
      case METHOD_POST:
      case METHOD_PUT:
      case METHOD_DELETE:
        if (ops.data is Map) {
          message += "\nData is Map: ${ops.data}";
        } else if (ops.data is FormData) {
          message +=
              "\nData is FormData: ${ops.data.fields}\nFiles: ${ops.data.files}";
        }
        break;
      default:
        break;
    }
    _logger.d(message);
    ops.connectTimeout = 30000;
    ops.receiveTimeout = 30000;
    handler.next(ops);
  }

  _responseInterceptor(Response r, ResponseInterceptorHandler handler) {
    _logger.i(
        "Response ${r.requestOptions.uri}: ${r.statusCode}\nData: ${r.data}");
    handler.next(r);
  }

  _errorInterceptor(DioError e, ErrorInterceptorHandler handler) {
    _logger.e(
        "${e.requestOptions.uri}\n${e.type} - ${e.message}\nStatus: ${e.response?.statusCode} -  ${e.response?.statusMessage}\nData: ${e.response?.data}");
    // if (_enableErrorHandler) ErrorHandling().onError(dioError);
    if (PCoreConfig.instance.coreOptions.errorInterceptor != null) {
      PCoreConfig.instance.coreOptions.errorInterceptor!(e);
    }
    handler.next(e);
  }
}
